/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Injector } from '@angular/core';
import { EventEmitter } from '@angular/core';
import { ControlValueAccessor, FormControl } from '@angular/forms';
import { ComboBoxComponent } from '@progress/kendo-angular-dropdowns';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare const TIME_ZONE_VALUE_ACCESSOR: any;
/**
 * Represents the Kendo UI TimeZone Editor component for Angular.
 * `TimeZoneEditorComponent` displays the currently loaded timezones.
 * Used for editing the `start` and `end` timezones of the `SchedulerEvent` objects.
 */
export declare class TimeZoneEditorComponent implements ControlValueAccessor {
    private injector;
    tzComboBox: ComboBoxComponent;
    tzComboBoxControl: ComboBoxComponent;
    /**
     * Specifies the width of the ComboBox which contains the names of the timezones.
     * @default 260
     */
    width: number;
    /**
     * Fires when the value of the component has changed.
     */
    valueChange: EventEmitter<string>;
    /**
     * @hidden
     */
    get focusableId(): string;
    /**
     * @hidden
     */
    get formControl(): FormControl;
    tz: string;
    tzNames: Array<string>;
    tzSource: Array<string>;
    constructor(injector: Injector);
    /**
     * @hidden
     */
    onTimeZoneChange(tzName: string): void;
    /**
     * @hidden
     */
    onTimeZoneFilterChange(value: string): void;
    /**
     * @hidden
     */
    writeValue(value: any): void;
    /**
     * @hidden
     */
    focus(): void;
    protected onTouchedCallback: Function;
    protected onChangeCallback: Function;
    /**
     * @hidden
     */
    registerOnChange(fn: any): void;
    /**
     * @hidden
     */
    registerOnTouched(fn: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TimeZoneEditorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TimeZoneEditorComponent, "kendo-timezone-editor", never, { "width": { "alias": "width"; "required": false; }; }, { "valueChange": "valueChange"; }, never, never, true, never>;
}
