/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DataBindingDirective } from './data-binding.directive';
import { SchedulerCustomMessagesComponent } from './localization/custom-messages.component';
import { PDFCommandDirective } from './pdf/pdf-command.directive';
import { PDFComponent } from './pdf/pdf.component';
import { SchedulerComponent } from './scheduler.component';
import { SlotSelectableDirective } from './views/common/slot-selectable.directive';
import { SchedulerViewDirective } from './views/scheduler-view.directive';
import { AgendaViewComponent } from './views/agenda/agenda-view.component';
import { MonthViewComponent } from './views/month/month-view.component';
import { MultiWeekViewComponent } from './views/month/multi-week-view.component';
import { DayViewComponent } from './views/multi-day/day-view.component';
import { MultiDayViewComponent } from './views/multi-day/multi-day-view.component';
import { WeekViewComponent } from './views/multi-day/week-view.component';
import { WorkWeekViewComponent } from './views/multi-day/work-week-view.component';
import { TimelineMonthViewComponent } from './views/timeline/timeline-month-view.component';
import { TimelineViewComponent } from './views/timeline/timeline-view.component';
import { TimelineWeekViewComponent } from './views/timeline/timeline-week-view.component';
import { YearViewComponent } from './views/year/year-view.component';
import { ReactiveEditingDirective } from './editing-directives/reactive-editing.directive';
import { EditDialogTemplateDirective } from './editing/edit-dialog-template.directive';
import { RecurrenceEditorComponent } from './editing/recurrence/recurrence-editor.component';
import { TimeZoneEditorComponent } from './editing/timezone-editor.component';
import { ToolbarNavigationComponent } from './toolbar/navigation.component';
import { ToolbarTemplateDirective } from './toolbar/toolbar-template.directive';
import { ToolbarViewSelectorComponent } from './toolbar/view-selector.component';
import { AgendaDateTemplateDirective } from './views/templates/agenda-date-template.directive';
import { AgendaTimeTemplateDirective } from './views/templates/agenda-time-template.directive';
import { AllDayEventTemplateDirective } from './views/templates/all-day-event-template.directive';
import { AllDaySlotTemplateDirective } from './views/templates/all-day-slot-template.directive';
import { DateHeaderTemplateDirective } from './views/templates/date-header-template.directive';
import { EventTemplateDirective } from './views/templates/event-template.directive';
import { GroupHeaderTemplateDirective } from './views/templates/group-header-template.directive';
import { MajorTimeHeaderTemplateDirective } from './views/templates/major-time-header-template.directive';
import { MinorTimeHeaderTemplateDirective } from './views/templates/minor-time-header-template.directive';
import { MonthDaySlotTemplateDirective } from './views/templates/month-day-slot-template.directive';
import { MultiWeekDaySlotTemplateDirective } from './views/templates/multi-week-day-slot-template.directive';
import { TimeSlotTemplateDirective } from './views/templates/time-slot-template.directive';
import { ShortcutsDirective } from './navigation/shortcuts.directive';
/**
 * Utility array that contains all Scheduler PDF related components and directives
 */
export const KENDO_SCHEDULERPDF = [
    PDFComponent,
    PDFCommandDirective
];
/**
 * Utility array that contains all `@progress/kendo-angular-scheduler` related components and directives
 */
export const KENDO_SCHEDULER = [
    SchedulerComponent,
    SchedulerCustomMessagesComponent,
    SchedulerViewDirective,
    DataBindingDirective,
    SlotSelectableDirective,
    PDFComponent,
    PDFCommandDirective,
    ShortcutsDirective,
    // views
    AgendaViewComponent,
    DayViewComponent,
    MonthViewComponent,
    MultiDayViewComponent,
    MultiWeekViewComponent,
    TimelineMonthViewComponent,
    TimelineViewComponent,
    TimelineWeekViewComponent,
    WeekViewComponent,
    WorkWeekViewComponent,
    YearViewComponent,
    // editing
    ReactiveEditingDirective,
    RecurrenceEditorComponent,
    TimeZoneEditorComponent,
    // toolbar
    ToolbarNavigationComponent,
    ToolbarTemplateDirective,
    ToolbarViewSelectorComponent,
    // templates
    AgendaDateTemplateDirective,
    AgendaTimeTemplateDirective,
    AllDayEventTemplateDirective,
    AllDaySlotTemplateDirective,
    DateHeaderTemplateDirective,
    EventTemplateDirective,
    EditDialogTemplateDirective,
    GroupHeaderTemplateDirective,
    MajorTimeHeaderTemplateDirective,
    MinorTimeHeaderTemplateDirective,
    MonthDaySlotTemplateDirective,
    MultiWeekDaySlotTemplateDirective,
    TimeSlotTemplateDirective,
];
