/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from './preventable-event';
/**
 * Arguments for the `drag` event.
 */
export class DragEvent extends PreventableEvent {
    /**
     * The original Scheduler event.
     */
    event;
    /**
     * The current `isAllDay` value.
     */
    isAllDay;
    /**
     * The data item of the event.
     */
    dataItem;
    /**
     * The new start date of the event.
     */
    start;
    /**
     * The new end date of the event.
     */
    end;
    /**
     * The current resources while dragging.
     */
    resources;
    /**
     * Sets the class to the drag hint ([see example]({% slug restrictions_scheduler %})).
     */
    setHintClass;
    /**
     * Sets the class to the slot over which the event is dragged.
     */
    setSlotClass;
    /**
     * A reference to the Scheduler instance that triggered the event.
     */
    sender;
    /**
     * @hidden
     */
    constructor(sender, args) {
        super();
        this.sender = sender;
        Object.assign(this, args);
    }
}
