/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from './preventable-event';
/**
 * Arguments for the `slotDragStart` event.
 * The event is preventable and if prevented, subsequent `slotDrag`, `slotDragEnd`, and `slotSelectionChange` will not be fired.
 */
export class SlotDragStartEvent extends PreventableEvent {
    /**
     * The start date of the slot selection.
     */
    start;
    /**
     * The end date of the slot selection.
     */
    end;
    /**
     * Indicates if the slot selection consists of all-day slots, or of time slots.
     */
    isAllDay;
    /**
     * The resources for the slot, if grouping by resource; otherwise all Scheduler resources.
     */
    resources;
    /**
     * The original DOM event.
     */
    originalEvent;
    /**
     * A reference to the Scheduler instance that triggered the event.
     */
    sender;
    /**
     * @hidden
     */
    constructor(sender, args) {
        super();
        this.sender = sender;
        Object.assign(this, args);
    }
}
