/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, Input } from '@angular/core';
import { ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export class Messages extends ComponentMessages {
    /**
     * The **All events** text that is displayed in the **Timeline** views when no vertical grouping is applied.
     */
    allEvents;
    /**
     * The **All day** text that is displayed in the *Day** and **Week** views.
     */
    allDay;
    /**
     * The date-header text that is displayed in the **Agenda** view.
     */
    dateHeader;
    /**
     * The time-header text that is displayed in the **Agenda** view.
     */
    timeHeader;
    /**
     * The event-header text that is displayed in the **Agenda** view.
     */
    eventHeader;
    /**
     * The title of the **Delete** icon.
     */
    deleteTitle;
    /**
     * The title of the **Next** navigation button.
     */
    nextTitle;
    /**
     * The title of the **Previous** navigation button.
     */
    previousTitle;
    /**
     * The text of the **Today** navigation button.
     */
    today;
    /**
     * The text of today's date in the header of the Calendar.
     */
    calendarToday;
    /**
     * The text of the **Show full day** button that is displayed in the footer of the **Day**, **Week**, and **Timeline** views.
     */
    showFullDay;
    /**
     * The text of the **Show work day** button that is displayed in the footer of the **Day**, **Week**, and **Timeline** views.
     */
    showWorkDay;
    /**
     * The title of the **Day** view.
     */
    dayViewTitle;
    /**
     * The title of the **Multi-Day** view.
     */
    multiDayViewTitle;
    /**
     * The title of the **Week** view.
     */
    weekViewTitle;
    /**
     * The title of the **Work Week** view.
     */
    workWeekViewTitle;
    /**
     * The title of the **Month** view.
     */
    monthViewTitle;
    /**
     * The title of the **Multi-Week** view.
     */
    multiWeekViewTitle;
    /**
     * The title of the **Timeline** view.
     */
    timelineViewTitle;
    /**
     * The title of the **Week** timeline view.
     */
    timelineWeekViewTitle;
    /**
     * The title of the **Month** timeline view.
     */
    timelineMonthViewTitle;
    /**
     * The title of the **Agenda** view.
     */
    agendaViewTitle;
    /**
     * The title of the **Year** view.
     */
    yearViewTitle;
    /**
     * The message displayed in **Year** view for any date that has no events.
     */
    yearViewNoEvents;
    /* ********************* */
    /* Editing Section Start */
    /* ********************* */
    /**
     * The text of the **Cancel** button displayed in the Scheduler dialogs.
     */
    cancel;
    /**
     * The text of the **Save** button displayed in the Scheduler dialogs.
     */
    save;
    /**
     * The text similar to 'Title' displayed in the Scheduler event editor.
     */
    editorEventTitle;
    /**
     * The text similar to 'Start' displayed in the Scheduler event editor.
     */
    editorEventStart;
    /**
     * The text similar to 'Start Time Zone' displayed in the Scheduler event editor.
     */
    editorEventStartTimeZone;
    /**
     * The text similar to 'End' displayed in the Scheduler event editor.
     */
    editorEventEnd;
    /**
     * The text similar to 'End Time Zone' displayed in the Scheduler event editor.
     */
    editorEventEndTimeZone;
    /**
     * The text similar to 'All Day Event' displayed in the Scheduler event editor.
     */
    editorEventAllDay;
    /**
     * The text similar to 'Description' displayed in the Scheduler event editor.
     */
    editorEventDescription;
    /**
     * The text similar to 'Use separate Start and End Time Zones' displayed in the Scheduler event editor.
     */
    editorEventSeparateTimeZones;
    /**
     * The text similar to 'Time Zone' displayed in the Scheduler event editor.
     */
    editorEventTimeZone;
    /**
     * The **Today** button text in the popup of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsToday;
    /**
     * The title of the **Toggle** button in the popup of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsToggle;
    /**
     * The title of the **Parent View** button in the popup of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsParentViewButton;
    /**
     * The text of the **Now** button in the popup footer of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsNow;
    /**
     * The label of the **Now** button in the popup footer of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsNowLabel;
    /**
     * The text of the **Accept** button in the popup footer of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsAccept;
    /**
     * The label of the **Accept** button in the popup footer of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsAcceptLabel;
    /**
     * The text of the **Cancel** button in the popup footer of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsCancel;
    /**
     * The label of the **Cancel** button in the popup footer of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsCancelLabel;
    /**
     * The text of the **Date** tab in the popup header of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsDateTab;
    /**
     * The label of the **Date** tab in the popup header of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsDateTabLabel;
    /**
     * The text of the **Time** tab in the popup header of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsTimeTab;
    /**
     * The label of the **Time** tab in the popup header of the DateTimePickers and DatePickers in the Scheduler event editor.
     */
    editorDateInputsTimeTabLabel;
    /**
     * The **Today** button text in the popup of the DatePickers in the Scheduler recurrence editor.
     */
    recurrenceEditorDateInputsToday;
    /**
     * The title of the **Toggle** button in the popup of the DatePickers in the Scheduler recurrence editor.
     */
    recurrenceEditorDateInputsToggle;
    /**
     * The title of the **Parent View** button in the popup of the DatePickers in the Scheduler recurrence editor.
     */
    recurrenceEditorDateInputsParentViewButton;
    /**
     * The title of the **Increment** button of the NumericTextBox in the Scheduler recurrence editor.
     */
    recurrenceEditorNumericIncrement;
    /**
     * The title of the **Decrement** button of the NumericTextBox in the Scheduler recurrence editor.
     */
    recurrenceEditorNumericDecrement;
    /**
     * The text similar to 'Repeat' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorRepeat;
    /**
     * The text similar to 'day(s)' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorDailyInterval;
    /**
     * The text similar to 'Repeat every' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorDailyRepeatEvery;
    /**
     * The text similar to 'week(s)' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorWeeklyInterval;
    /**
     * The text similar to 'Repeat every' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorWeeklyRepeatEvery;
    /**
     * The text similar to 'Repeat on' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorWeeklyRepeatOn;
    /**
     * The text similar to 'Day' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorMonthlyDay;
    /**
     * The text similar to 'month(s)' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorMonthlyInterval;
    /**
     * The text similar to 'Repeat every' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorMonthlyRepeatEvery;
    /**
     * The text similar to 'Repeat on' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorMonthlyRepeatOn;
    /**
     * The text similar to 'of' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorYearlyOf;
    /**
     * The text similar to 'Repeat every' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorYearlyRepeatEvery;
    /**
     * The text similar to 'Repeat on' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorYearlyRepeatOn;
    /**
     * The text similar to 'year(s)' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorYearlyInterval;
    /**
     * The text similar to 'Daily' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorFrequenciesDaily;
    /**
     * The text similar to 'Monthly' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorFrequenciesMonthly;
    /**
     * The text similar to 'Never' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorFrequenciesNever;
    /**
     * The text similar to 'Weekly' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorFrequenciesWeekly;
    /**
     * The text similar to 'Yearly' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorFrequenciesYearly;
    /**
     * The text similar to 'First' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorOffsetPositionsFirst;
    /**
     * The text similar to 'Second' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorOffsetPositionsSecond;
    /**
     * The text similar to 'Third' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorOffsetPositionsThird;
    /**
     * The text similar to 'Fourth' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorOffsetPositionsFourth;
    /**
     * The text similar to 'Last' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorOffsetPositionsLast;
    /**
     * The text similar to 'Day' displayed in the repeat by section of the monthly recurrence pattern.
     */
    recurrenceEditorWeekdaysDay;
    /**
     * The text similar to 'Weekday' displayed in the repeat by section of the monthly recurrence pattern.
     */
    recurrenceEditorWeekdaysWeekday;
    /**
     * The text similar to 'Weekend Day' displayed in the repeat by section of the monthly recurrence pattern.
     */
    recurrenceEditorWeekdaysWeekendday;
    /**
     * The text similar to 'After' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorEndAfter;
    /**
     * The text similar to 'occurrence(s)' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorEndOccurrence;
    /**
     * The text similar to 'End' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorEndLabel;
    /**
     * The text similar to 'Never' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorEndNever;
    /**
     * The text similar to 'On' displayed in the Scheduler recurrence editor.
     */
    recurrenceEditorEndOn;
    /* ******************* */
    /* Editing Section End */
    /* ******************* */
    /* ********************* */
    /* Dialogs Section Start */
    /* ********************* */
    /**
     * The text similar to **Event** displayed as title of the Scheduler event editor.
     */
    editorTitle;
    /**
     * The text of the **Delete** button displayed in the Scheduler remove confirmation dialog.
     */
    destroy;
    /**
     * The text similar to **Are you sure you want to delete this event?** displayed in Scheduler remove confirmation dialog.
     */
    deleteConfirmation;
    /**
     * The text similar to **Do you want to edit only this event occurrence or the whole series?** displayed in the Scheduler recurring confirmation dialog.
     */
    editRecurringConfirmation;
    /**
     * The text of the **Edit current occurrence** button displayed in the Scheduler recurring confirmation dialog.
     */
    editOccurrence;
    /**
     * The text of the **Edit the series** button displayed in the Scheduler recurring confirmation dialog.
     */
    editSeries;
    /**
     * The text similar to **Do you want to delete only this event occurrence or the whole series?** displayed in the Scheduler recurring confirmation dialog.
     */
    deleteRecurringConfirmation;
    /**
     * The text of the **Delete current occurrence** button displayed in the Scheduler recurring confirmation dialog.
     */
    deleteOccurrence;
    /**
     * The text similar of the **Delete the series** button displayed in the Scheduler recurring confirmation dialog.
     */
    deleteSeries;
    /**
     * The title of the remove confirmation dialog, similar to **Delete event**.
     */
    deleteDialogTitle;
    /**
     * The title of the recurring remove confirmation dialog, similar to **Delete Recurring Item**.
     */
    deleteRecurringDialogTitle;
    /**
     * The title of the recurring edit confirmation dialog, similar to **Edit Recurring Item**.
     */
    editRecurringDialogTitle;
    /**
     * The value of the aria-label attribute of the `<select>` element used for switching the Scheduler views.
     */
    selectView;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: Messages, inputs: { allEvents: "allEvents", allDay: "allDay", dateHeader: "dateHeader", timeHeader: "timeHeader", eventHeader: "eventHeader", deleteTitle: "deleteTitle", nextTitle: "nextTitle", previousTitle: "previousTitle", today: "today", calendarToday: "calendarToday", showFullDay: "showFullDay", showWorkDay: "showWorkDay", dayViewTitle: "dayViewTitle", multiDayViewTitle: "multiDayViewTitle", weekViewTitle: "weekViewTitle", workWeekViewTitle: "workWeekViewTitle", monthViewTitle: "monthViewTitle", multiWeekViewTitle: "multiWeekViewTitle", timelineViewTitle: "timelineViewTitle", timelineWeekViewTitle: "timelineWeekViewTitle", timelineMonthViewTitle: "timelineMonthViewTitle", agendaViewTitle: "agendaViewTitle", yearViewTitle: "yearViewTitle", yearViewNoEvents: "yearViewNoEvents", cancel: "cancel", save: "save", editorEventTitle: "editorEventTitle", editorEventStart: "editorEventStart", editorEventStartTimeZone: "editorEventStartTimeZone", editorEventEnd: "editorEventEnd", editorEventEndTimeZone: "editorEventEndTimeZone", editorEventAllDay: "editorEventAllDay", editorEventDescription: "editorEventDescription", editorEventSeparateTimeZones: "editorEventSeparateTimeZones", editorEventTimeZone: "editorEventTimeZone", editorDateInputsToday: "editorDateInputsToday", editorDateInputsToggle: "editorDateInputsToggle", editorDateInputsParentViewButton: "editorDateInputsParentViewButton", editorDateInputsNow: "editorDateInputsNow", editorDateInputsNowLabel: "editorDateInputsNowLabel", editorDateInputsAccept: "editorDateInputsAccept", editorDateInputsAcceptLabel: "editorDateInputsAcceptLabel", editorDateInputsCancel: "editorDateInputsCancel", editorDateInputsCancelLabel: "editorDateInputsCancelLabel", editorDateInputsDateTab: "editorDateInputsDateTab", editorDateInputsDateTabLabel: "editorDateInputsDateTabLabel", editorDateInputsTimeTab: "editorDateInputsTimeTab", editorDateInputsTimeTabLabel: "editorDateInputsTimeTabLabel", recurrenceEditorDateInputsToday: "recurrenceEditorDateInputsToday", recurrenceEditorDateInputsToggle: "recurrenceEditorDateInputsToggle", recurrenceEditorDateInputsParentViewButton: "recurrenceEditorDateInputsParentViewButton", recurrenceEditorNumericIncrement: "recurrenceEditorNumericIncrement", recurrenceEditorNumericDecrement: "recurrenceEditorNumericDecrement", recurrenceEditorRepeat: "recurrenceEditorRepeat", recurrenceEditorDailyInterval: "recurrenceEditorDailyInterval", recurrenceEditorDailyRepeatEvery: "recurrenceEditorDailyRepeatEvery", recurrenceEditorWeeklyInterval: "recurrenceEditorWeeklyInterval", recurrenceEditorWeeklyRepeatEvery: "recurrenceEditorWeeklyRepeatEvery", recurrenceEditorWeeklyRepeatOn: "recurrenceEditorWeeklyRepeatOn", recurrenceEditorMonthlyDay: "recurrenceEditorMonthlyDay", recurrenceEditorMonthlyInterval: "recurrenceEditorMonthlyInterval", recurrenceEditorMonthlyRepeatEvery: "recurrenceEditorMonthlyRepeatEvery", recurrenceEditorMonthlyRepeatOn: "recurrenceEditorMonthlyRepeatOn", recurrenceEditorYearlyOf: "recurrenceEditorYearlyOf", recurrenceEditorYearlyRepeatEvery: "recurrenceEditorYearlyRepeatEvery", recurrenceEditorYearlyRepeatOn: "recurrenceEditorYearlyRepeatOn", recurrenceEditorYearlyInterval: "recurrenceEditorYearlyInterval", recurrenceEditorFrequenciesDaily: "recurrenceEditorFrequenciesDaily", recurrenceEditorFrequenciesMonthly: "recurrenceEditorFrequenciesMonthly", recurrenceEditorFrequenciesNever: "recurrenceEditorFrequenciesNever", recurrenceEditorFrequenciesWeekly: "recurrenceEditorFrequenciesWeekly", recurrenceEditorFrequenciesYearly: "recurrenceEditorFrequenciesYearly", recurrenceEditorOffsetPositionsFirst: "recurrenceEditorOffsetPositionsFirst", recurrenceEditorOffsetPositionsSecond: "recurrenceEditorOffsetPositionsSecond", recurrenceEditorOffsetPositionsThird: "recurrenceEditorOffsetPositionsThird", recurrenceEditorOffsetPositionsFourth: "recurrenceEditorOffsetPositionsFourth", recurrenceEditorOffsetPositionsLast: "recurrenceEditorOffsetPositionsLast", recurrenceEditorWeekdaysDay: "recurrenceEditorWeekdaysDay", recurrenceEditorWeekdaysWeekday: "recurrenceEditorWeekdaysWeekday", recurrenceEditorWeekdaysWeekendday: "recurrenceEditorWeekdaysWeekendday", recurrenceEditorEndAfter: "recurrenceEditorEndAfter", recurrenceEditorEndOccurrence: "recurrenceEditorEndOccurrence", recurrenceEditorEndLabel: "recurrenceEditorEndLabel", recurrenceEditorEndNever: "recurrenceEditorEndNever", recurrenceEditorEndOn: "recurrenceEditorEndOn", editorTitle: "editorTitle", destroy: "destroy", deleteConfirmation: "deleteConfirmation", editRecurringConfirmation: "editRecurringConfirmation", editOccurrence: "editOccurrence", editSeries: "editSeries", deleteRecurringConfirmation: "deleteRecurringConfirmation", deleteOccurrence: "deleteOccurrence", deleteSeries: "deleteSeries", deleteDialogTitle: "deleteDialogTitle", deleteRecurringDialogTitle: "deleteRecurringDialogTitle", editRecurringDialogTitle: "editRecurringDialogTitle", selectView: "selectView" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, decorators: [{
            type: Directive
        }], propDecorators: { allEvents: [{
                type: Input
            }], allDay: [{
                type: Input
            }], dateHeader: [{
                type: Input
            }], timeHeader: [{
                type: Input
            }], eventHeader: [{
                type: Input
            }], deleteTitle: [{
                type: Input
            }], nextTitle: [{
                type: Input
            }], previousTitle: [{
                type: Input
            }], today: [{
                type: Input
            }], calendarToday: [{
                type: Input
            }], showFullDay: [{
                type: Input
            }], showWorkDay: [{
                type: Input
            }], dayViewTitle: [{
                type: Input
            }], multiDayViewTitle: [{
                type: Input
            }], weekViewTitle: [{
                type: Input
            }], workWeekViewTitle: [{
                type: Input
            }], monthViewTitle: [{
                type: Input
            }], multiWeekViewTitle: [{
                type: Input
            }], timelineViewTitle: [{
                type: Input
            }], timelineWeekViewTitle: [{
                type: Input
            }], timelineMonthViewTitle: [{
                type: Input
            }], agendaViewTitle: [{
                type: Input
            }], yearViewTitle: [{
                type: Input
            }], yearViewNoEvents: [{
                type: Input
            }], cancel: [{
                type: Input
            }], save: [{
                type: Input
            }], editorEventTitle: [{
                type: Input
            }], editorEventStart: [{
                type: Input
            }], editorEventStartTimeZone: [{
                type: Input
            }], editorEventEnd: [{
                type: Input
            }], editorEventEndTimeZone: [{
                type: Input
            }], editorEventAllDay: [{
                type: Input
            }], editorEventDescription: [{
                type: Input
            }], editorEventSeparateTimeZones: [{
                type: Input
            }], editorEventTimeZone: [{
                type: Input
            }], editorDateInputsToday: [{
                type: Input
            }], editorDateInputsToggle: [{
                type: Input
            }], editorDateInputsParentViewButton: [{
                type: Input
            }], editorDateInputsNow: [{
                type: Input
            }], editorDateInputsNowLabel: [{
                type: Input
            }], editorDateInputsAccept: [{
                type: Input
            }], editorDateInputsAcceptLabel: [{
                type: Input
            }], editorDateInputsCancel: [{
                type: Input
            }], editorDateInputsCancelLabel: [{
                type: Input
            }], editorDateInputsDateTab: [{
                type: Input
            }], editorDateInputsDateTabLabel: [{
                type: Input
            }], editorDateInputsTimeTab: [{
                type: Input
            }], editorDateInputsTimeTabLabel: [{
                type: Input
            }], recurrenceEditorDateInputsToday: [{
                type: Input
            }], recurrenceEditorDateInputsToggle: [{
                type: Input
            }], recurrenceEditorDateInputsParentViewButton: [{
                type: Input
            }], recurrenceEditorNumericIncrement: [{
                type: Input
            }], recurrenceEditorNumericDecrement: [{
                type: Input
            }], recurrenceEditorRepeat: [{
                type: Input
            }], recurrenceEditorDailyInterval: [{
                type: Input
            }], recurrenceEditorDailyRepeatEvery: [{
                type: Input
            }], recurrenceEditorWeeklyInterval: [{
                type: Input
            }], recurrenceEditorWeeklyRepeatEvery: [{
                type: Input
            }], recurrenceEditorWeeklyRepeatOn: [{
                type: Input
            }], recurrenceEditorMonthlyDay: [{
                type: Input
            }], recurrenceEditorMonthlyInterval: [{
                type: Input
            }], recurrenceEditorMonthlyRepeatEvery: [{
                type: Input
            }], recurrenceEditorMonthlyRepeatOn: [{
                type: Input
            }], recurrenceEditorYearlyOf: [{
                type: Input
            }], recurrenceEditorYearlyRepeatEvery: [{
                type: Input
            }], recurrenceEditorYearlyRepeatOn: [{
                type: Input
            }], recurrenceEditorYearlyInterval: [{
                type: Input
            }], recurrenceEditorFrequenciesDaily: [{
                type: Input
            }], recurrenceEditorFrequenciesMonthly: [{
                type: Input
            }], recurrenceEditorFrequenciesNever: [{
                type: Input
            }], recurrenceEditorFrequenciesWeekly: [{
                type: Input
            }], recurrenceEditorFrequenciesYearly: [{
                type: Input
            }], recurrenceEditorOffsetPositionsFirst: [{
                type: Input
            }], recurrenceEditorOffsetPositionsSecond: [{
                type: Input
            }], recurrenceEditorOffsetPositionsThird: [{
                type: Input
            }], recurrenceEditorOffsetPositionsFourth: [{
                type: Input
            }], recurrenceEditorOffsetPositionsLast: [{
                type: Input
            }], recurrenceEditorWeekdaysDay: [{
                type: Input
            }], recurrenceEditorWeekdaysWeekday: [{
                type: Input
            }], recurrenceEditorWeekdaysWeekendday: [{
                type: Input
            }], recurrenceEditorEndAfter: [{
                type: Input
            }], recurrenceEditorEndOccurrence: [{
                type: Input
            }], recurrenceEditorEndLabel: [{
                type: Input
            }], recurrenceEditorEndNever: [{
                type: Input
            }], recurrenceEditorEndOn: [{
                type: Input
            }], editorTitle: [{
                type: Input
            }], destroy: [{
                type: Input
            }], deleteConfirmation: [{
                type: Input
            }], editRecurringConfirmation: [{
                type: Input
            }], editOccurrence: [{
                type: Input
            }], editSeries: [{
                type: Input
            }], deleteRecurringConfirmation: [{
                type: Input
            }], deleteOccurrence: [{
                type: Input
            }], deleteSeries: [{
                type: Input
            }], deleteDialogTitle: [{
                type: Input
            }], deleteRecurringDialogTitle: [{
                type: Input
            }], editRecurringDialogTitle: [{
                type: Input
            }], selectView: [{
                type: Input
            }] } });
