/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SchedulerComponent } from '../scheduler.component';
import { ExtendedSlotRange } from '../types/slot-selection';
/**
 * Arguments for the `slotDrag` event.
 */
export declare class SlotDragEvent implements ExtendedSlotRange {
    /**
     * The start date of the slot selection.
     */
    start: Date;
    /**
     * The end date of the slot selection.
     */
    end: Date;
    /**
     * Indicates if the slot selection consists of all-day slots, or of time slots.
     */
    isAllDay: boolean;
    /**
     * The resources for the slot, if grouping by resource; otherwise all Scheduler resources.
     */
    resources: any[];
    /**
     * The original DOM event.
     */
    originalEvent: PointerEvent;
    /**
     * A reference to the Scheduler instance that triggered the event.
     */
    sender: SchedulerComponent;
    /**
     * @hidden
     */
    constructor(sender: SchedulerComponent, args: ExtendedSlotRange);
}
