/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, TemplateRef, OnDestroy, ChangeDetectorRef } from '@angular/core';
import { PopupService } from '@progress/kendo-angular-popup';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { ToolbarService } from './toolbar.service';
import { ToolbarContext } from './toolbar-context';
import { CalendarComponent, CalendarView } from '@progress/kendo-angular-dateinputs';
import { ViewContextService } from '../views/view-context.service';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
interface DateRangeText {
    short: string;
    long: string;
    current: string;
}
/**
 * A toolbar component which contains the controls for date navigation
 * ([see example]({% slug toolbar_scheduler %}#toc-including-the-built-in-components)).
 *
 * To render the **Previous**, **Today**, **Next**, and **Date picker**
 * buttons, include the component in the
 * [toolbar template]({% slug api_scheduler_toolbartemplatedirective %}).
 */
export declare class ToolbarNavigationComponent implements OnDestroy {
    private popupService;
    private toolbarService;
    private localization;
    private cd;
    private viewContext;
    set calendar(calendar: CalendarComponent);
    hostClass: boolean;
    /**
     * @hidden
     */
    min: Date;
    /**
     * @hidden
     */
    max: Date;
    /**
     * @hidden
     */
    get todayText(): string;
    /**
     * Sets the [`activeView`]({% slug api_dateinputs_calendarcomponent %}#toc-activeview) of the Calendar in the navigation component.
     *
     * @default month
     */
    activeView: CalendarView;
    /**
     * Sets the [`bottomView`]({% slug api_dateinputs_calendarcomponent %}#toc-bottomview) of the Calendar in the navigation component.
     *
     * @default month
     */
    bottomView: CalendarView;
    /**
     * @hidden
     */
    get calendarTodayText(): string;
    /**
     * @hidden
     */
    get nextText(): string;
    /**
     * @hidden
     */
    get previousText(): string;
    /**
     * @hidden
     */
    get ctx(): ToolbarContext;
    /**
     * @hidden
     */
    dateRangeText: DateRangeText;
    /**
     * @hidden
     */
    svgIcon(name: string): SVGIcon;
    private popupRef;
    private subs;
    private isMouseDown;
    constructor(popupService: PopupService, toolbarService: ToolbarService, localization: LocalizationService, cd: ChangeDetectorRef, viewContext: ViewContextService);
    /**
     * @hidden
     */
    onBlur(): void;
    /**
     * @hidden
     */
    onMouseDown(): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    toggleSelectedDate(anchor: ElementRef, template: TemplateRef<any>): boolean;
    /**
     * @hidden
     */
    selectDate(value: Date): void;
    /**
     * @hidden
     */
    prevClick(): boolean;
    /**
     * @hidden
     */
    nextClick(): boolean;
    /**
     * @hidden
     */
    todayClick(): boolean;
    protected closePopup(): void;
    private setDateRangeText;
    get arrowIcons(): string[];
    get arrowSVGIcons(): string[];
    static ɵfac: i0.ɵɵFactoryDeclaration<ToolbarNavigationComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ToolbarNavigationComponent, "[kendoSchedulerToolbarNavigation]", never, { "min": { "alias": "min"; "required": false; }; "max": { "alias": "max"; "required": false; }; "activeView": { "alias": "activeView"; "required": false; }; "bottomView": { "alias": "bottomView"; "required": false; }; }, {}, never, never, true, never>;
}
export {};
