/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Observable } from 'rxjs';
import { NavigationAction } from '../types';
import { ToolbarContext } from './toolbar-context';
import * as i0 from "@angular/core";
/**
 * A service for communication with the toolbar controls
 * which is used by the toolbar components for publishing navigation actions
 * ([see example]({% slug toolbar_scheduler %}#toc-using-the-toolbar-service)).
 */
export declare class ToolbarService {
    /**
     * A stream of navigation actions that is intended for consumption by the toolbar.
     *
     * @hidden
     */
    readonly action: Observable<NavigationAction>;
    /**
     * The context for the built-in navigation components.
     *
     * @hidden
     */
    context: ToolbarContext;
    private actionSource;
    /** @hidden */
    constructor();
    /**
     * Emits the specified navigation action.
     *
     * @param action - The navigation action that will be executed.
     */
    navigate(action: NavigationAction): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ToolbarService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ToolbarService>;
}
