/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnDestroy } from '@angular/core';
import { SchedulerView } from '../types';
import { ToolbarService } from './toolbar.service';
import { ToolbarContext } from './toolbar-context';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * A toolbar component which contains the controls for switching the views
 * ([see example]({% slug toolbar_scheduler %}#toc-including-the-built-in-components)).
 *
 * To render the view-selection buttons, include the component in the
 * [toolbar template]({% slug api_scheduler_toolbartemplatedirective %}).
 */
export declare class ToolbarViewSelectorComponent implements OnDestroy {
    private service;
    private localization;
    /**
     * Specifies the current width of the Toolbar (in pixels) so the responsive calculations can be made.
     * The ([schedulerResize]({% slug api_scheduler_schedulercomponent %}#toc-schedulerresize)) event can be used in order to obtain the Toolbar width.
     */
    toolbarWidth: number;
    /**
     * Specifies the Toolbar width (in pixels) at which the responsive behavior should be enabled.
     * The responsive behavior means that the ButtonGroup with the views will be replaced by a `select` element.
     *
     * @default 1024
     */
    responsiveBreakpoint: number;
    /**
     * @hidden
     */
    get ctx(): ToolbarContext;
    /**
     * @hidden
     */
    get selectView(): string;
    private detachDomEvents;
    constructor(service: ToolbarService, localization: LocalizationService);
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    select(view: SchedulerView): void;
    /**
     * @hidden
     */
    onChange(e: any): void;
    /**
     * @hidden
     */
    isSelected(view: SchedulerView): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<ToolbarViewSelectorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ToolbarViewSelectorComponent, "[kendoSchedulerToolbarViewSelector]", never, { "toolbarWidth": { "alias": "toolbarWidth"; "required": false; }; "responsiveBreakpoint": { "alias": "responsiveBreakpoint"; "required": false; }; }, {}, never, never, true, never>;
}
