/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { ConfigurationViewBase } from '../common/configuration-view-base';
import { ViewContextService } from '../view-context.service';
import { ViewStateService } from '../view-state.service';
import { AgendaTimeTemplateDirective, AgendaDateTemplateDirective } from '../templates';
import * as i0 from "@angular/core";
/**
 * The component for rendering the **Agenda** view.
 */
export declare class AgendaViewComponent extends ConfigurationViewBase {
    /**
     * @hidden
     */
    get title(): string;
    /**
     * The long-date format for displaying the
     * selected date in the Scheduler toolbar.
     * Defaults to `{0:D} - {1:D}`,
     * where `0` is the start and `1` is the end date
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     */
    selectedDateFormat: string;
    /**
     * The short-date format for displaying the
     * selected date in the Scheduler toolbar.
     * Defaults to `{0:d} - {1:d}`,
     * where `0` is the start and `1` is the end date
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * @default '{0:d} - {1:d}'
     */
    selectedShortDateFormat: string;
    /**
     * Specifies the number of days that the view will render.
     * @default 7
     */
    numberOfDays: number;
    /**
     * @hidden
     */
    agendaTimeTemplate: AgendaTimeTemplateDirective;
    /**
     * @hidden
     */
    agendaDateTemplate: AgendaDateTemplateDirective;
    /**
     * The invariant name for this view (`agenda`).
     * @default 'agenda'
     */
    readonly name: string;
    constructor(localization: LocalizationService, changeDetector: ChangeDetectorRef, viewContext: ViewContextService, viewState: ViewStateService);
    static ɵfac: i0.ɵɵFactoryDeclaration<AgendaViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AgendaViewComponent, "kendo-scheduler-agenda-view", never, { "selectedDateFormat": { "alias": "selectedDateFormat"; "required": false; }; "selectedShortDateFormat": { "alias": "selectedShortDateFormat"; "required": false; }; "numberOfDays": { "alias": "numberOfDays"; "required": false; }; }, {}, ["agendaTimeTemplate", "agendaDateTemplate"], never, true, never>;
}
