/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { BaseSlotDirective } from '../view-items/base-slot.directive';
import { MonthSlotService } from './month-slot.service';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class MonthSlotComponent extends BaseSlotDirective {
    private cdr;
    style: string;
    showMoreButton: boolean;
    moreHorizontalIcon: SVGIcon;
    resourcesByIndex: any;
    monthDaySlotTemplateRef: any;
    eventsPerDay: number | 'auto';
    eventHeight: number | 'auto';
    adaptiveSlotHeight: boolean;
    set day(value: Date);
    /**
     * For the slot template we need the day value without the UTC conversion
     * - timezone does not matter for the day part in this case as the calendar month view is the same for every timezone
     * otherwise the date is incorrect for some timezones (e.g. LA timezone) -
     * For example, it displays Feb. 8, 2023 to be Thursday, wherease it is Wednesday
     */
    get day(): Date;
    set start(value: Date);
    get start(): Date;
    isDaySlot: boolean;
    get end(): Date;
    isFirstDayOfMonth(day: Date): boolean;
    get linkHeight(): number;
    private startDate;
    private _day;
    private _linkHeight;
    constructor(element: ElementRef, slotService: MonthSlotService, localization: LocalizationService, cdr: ChangeDetectorRef);
    ngOnDestroy(): void;
    showMore(rect: any): void;
    hideMore(): void;
    invalidate(): void;
    private removeShowMore;
    static ɵfac: i0.ɵɵFactoryDeclaration<MonthSlotComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MonthSlotComponent, "[monthSlot]", never, { "resourcesByIndex": { "alias": "resourcesByIndex"; "required": false; }; "monthDaySlotTemplateRef": { "alias": "monthDaySlotTemplateRef"; "required": false; }; "eventsPerDay": { "alias": "eventsPerDay"; "required": false; }; "eventHeight": { "alias": "eventHeight"; "required": false; }; "adaptiveSlotHeight": { "alias": "adaptiveSlotHeight"; "required": false; }; "day": { "alias": "monthSlot"; "required": false; }; }, {}, never, never, true, never>;
}
