/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnDestroy, ChangeDetectorRef, SimpleChanges, OnChanges } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { IntlService } from '@progress/kendo-angular-intl';
import { DateRange } from '../../types';
import { ConfigurationViewBase } from '../common/configuration-view-base';
import { ViewContextService } from '../view-context.service';
import { ViewStateService } from '../view-state.service';
import { MonthDaySlotTemplateDirective } from '../templates';
import { Day } from '@progress/kendo-date-math';
import * as i0 from "@angular/core";
/**
 * The component for rendering the **Month** view.
 */
export declare class MonthViewComponent extends ConfigurationViewBase implements OnDestroy, OnChanges {
    private intl;
    /**
     * @hidden
     */
    get title(): string;
    /**
     * The number of events to be rendered per day. Setting this property to 'auto'
     * will display all events in the respective slot
     * ([see example](slug:month_views_scheduler#setting-the-number-of-events-per-day)).
     * > When set to `'auto'` it will automatically set the `adaptiveSlotHeight` property to `true`.
     * > If set to `0` it will be normalized internally to `1`.
     * @default 2
     */
    set eventsPerDay(events: number | 'auto');
    get eventsPerDay(): number | 'auto';
    private _eventsPerDay;
    /**
     * The height of the rendered events. Setting this property to 'auto' will
     * set the height of each event automatically based on its content
     * ([see example](slug:month_views_scheduler#configuring-the-height-of-the-scheduler-events)).
     * > When set to `'auto'` it will automatically set the `adaptiveSlotHeight` property to `true`.
     */
    eventHeight: number | 'auto';
    /**
     * Increases the slot group (row) height when containing events up to the number of displayed events
     * and reduces its height if there are less events for that specific slot group (row)
     * ([see example](slug:month_views_scheduler#enabling-the-adaptive-slot-height-of-the-scheduler)).
     * @default false
     */
    adaptiveSlotHeight: boolean;
    /**
     * The long-date format for displaying the
     * selected date in the Scheduler toolbar.
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * @default '{0:Y}'
     */
    selectedDateFormat: string;
    /**
     * The short-date format for displaying the
     * selected date in the Scheduler toolbar.
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * @default '{0:y}'
     */
    selectedShortDateFormat: string;
    monthDaySlotTemplate: MonthDaySlotTemplateDirective;
    /**
     * The invariant name for this view.
     * @default 'month'
     */
    readonly name: string;
    get viewEventHeight(): number | 'auto';
    constructor(localization: LocalizationService, changeDetector: ChangeDetectorRef, viewContext: ViewContextService, viewState: ViewStateService, intl: IntlService);
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * @hidden
     */
    dateRange(date: Date, weekStart: Day): DateRange;
    /**
     * @hidden
     */
    newRange(date: Date, direction?: 1 | -1): Date;
    static ɵfac: i0.ɵɵFactoryDeclaration<MonthViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MonthViewComponent, "kendo-scheduler-month-view", never, { "eventsPerDay": { "alias": "eventsPerDay"; "required": false; }; "eventHeight": { "alias": "eventHeight"; "required": false; }; "adaptiveSlotHeight": { "alias": "adaptiveSlotHeight"; "required": false; }; "selectedDateFormat": { "alias": "selectedDateFormat"; "required": false; }; "selectedShortDateFormat": { "alias": "selectedShortDateFormat"; "required": false; }; }, {}, ["monthDaySlotTemplate"], never, true, never>;
}
