/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { MultiDayViewBase } from './multi-day-view-base';
import { ViewContextService } from '../view-context.service';
import { ViewStateService } from '../view-state.service';
import { AllDaySlotTemplateDirective, AllDayEventTemplateDirective } from '../templates';
import * as i0 from "@angular/core";
/**
 * The component for rendering the **Day** view.
 */
export declare class DayViewComponent extends MultiDayViewBase {
    /**
     * @hidden
     */
    get title(): string;
    /**
     * The long-date format for displaying the
     * selected date in the Scheduler toolbar.
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * @default '{0:D}'
     */
    set selectedDateFormat(value: string);
    get selectedDateFormat(): string;
    /**
     * The short-date format for displaying the
     * selected date in the Scheduler toolbar.
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * @default '{0:d}'
     */
    set selectedShortDateFormat(value: string);
    get selectedShortDateFormat(): string;
    /**
     * @hidden
     */
    allDaySlotTemplate: AllDaySlotTemplateDirective;
    /**
     * @hidden
     */
    allDayEventTemplate: AllDayEventTemplateDirective;
    /**
     * The invariant name for this view.
     * @default 'day'
     */
    readonly name: string;
    private _selectedDateFormat;
    private _selectedShortDateFormat;
    constructor(localization: LocalizationService, changeDetector: ChangeDetectorRef, viewContext: ViewContextService, viewState: ViewStateService);
    static ɵfac: i0.ɵɵFactoryDeclaration<DayViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DayViewComponent, "kendo-scheduler-day-view", never, { "selectedDateFormat": { "alias": "selectedDateFormat"; "required": false; }; "selectedShortDateFormat": { "alias": "selectedShortDateFormat"; "required": false; }; }, {}, ["allDaySlotTemplate", "allDayEventTemplate"], never, true, never>;
}
