/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { ViewContextService } from '../view-context.service';
import { ViewStateService } from '../view-state.service';
import { DayViewComponent } from './day-view.component';
import * as i0 from "@angular/core";
/**
 * The component for rendering the **Multi-Day** view.
 */
export declare class MultiDayViewComponent extends DayViewComponent {
    /**
     * The long-date format for displaying the
     * selected date in the Scheduler toolbar.
     * Defaults to `{0:D} - {1:D}` for multiple days and `{0:D}` for a single day
     * ([more information](slug:parsingandformatting_intl#toc-date-formatting)).
     * @default '{0:D} - {1:D}'
     */
    set selectedDateFormat(value: string);
    get selectedDateFormat(): string;
    /**
     * The short date format for displaying the
     * selected date in the Scheduler toolbar.
     * Defaults to `{0:d} - {1:d}` for multiple days and `{0:d}` for a single day
     * ([more information](slug:parsingandformatting_intl#toc-date-formatting)).
     * @default '{0:d} - {1:d}'
     */
    set selectedShortDateFormat(value: string);
    get selectedShortDateFormat(): string;
    /**
     * Specifies the number of days that the view will render.
     * @default 1
     */
    numberOfDays: number;
    /**
     * @hidden
     */
    get title(): string;
    /**
     * The invariant name for this view.
     * @default 'multi-day'
     */
    readonly name: string;
    private get defaultDateFormat();
    private get defaultShortDateFormat();
    private dateFormat;
    private shortDateFormat;
    constructor(localization: LocalizationService, changeDetector: ChangeDetectorRef, viewContext: ViewContextService, viewState: ViewStateService);
    static ɵfac: i0.ɵɵFactoryDeclaration<MultiDayViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MultiDayViewComponent, "kendo-scheduler-multi-day-view", never, { "selectedDateFormat": { "alias": "selectedDateFormat"; "required": false; }; "selectedShortDateFormat": { "alias": "selectedShortDateFormat"; "required": false; }; "numberOfDays": { "alias": "numberOfDays"; "required": false; }; }, {}, never, never, true, never>;
}
