/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { MultiDayViewBase } from './multi-day-view-base';
import { IntlService } from '@progress/kendo-angular-intl';
import { ViewContextService } from '../view-context.service';
import { ViewStateService } from '../view-state.service';
import { AllDaySlotTemplateDirective, AllDayEventTemplateDirective } from '../templates';
import * as i0 from "@angular/core";
/**
 * The component for rendering the **Week** view.
 */
export declare class WeekViewComponent extends MultiDayViewBase {
    protected intl: IntlService;
    /**
     * @hidden
     */
    get title(): string;
    /**
     * The long-date format for displaying the
     * selected date in the Scheduler toolbar.
     * Defaults to `{0:D} - {1:D}`,
     * where `0` is the start and `1` is the end date
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting).
     * @default '{0:D} - {1:D}'
     */
    selectedDateFormat: string;
    /**
     * The short date format for displaying the
     * selected date in the Scheduler toolbar.
     * Defaults to `{0:d} - {1:d}`,
     * where `0` is the start and `1` is the end date
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting).
     * @default '{0:d} - {1:d}'
     */
    selectedShortDateFormat: string;
    /**
     * @hidden
     */
    allDaySlotTemplate: AllDaySlotTemplateDirective;
    /**
     * @hidden
     */
    allDayEventTemplate: AllDayEventTemplateDirective;
    /**
     * The invariant name for this view.
     * @default 'week'
     */
    readonly name: string;
    constructor(intl: IntlService, localization: LocalizationService, changeDetector: ChangeDetectorRef, viewContext: ViewContextService, viewState: ViewStateService);
    /**
     * @hidden
     */
    getStartDate(selectedDate: Date): Date;
    static ɵfac: i0.ɵɵFactoryDeclaration<WeekViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<WeekViewComponent, "kendo-scheduler-week-view", never, { "selectedDateFormat": { "alias": "selectedDateFormat"; "required": false; }; "selectedShortDateFormat": { "alias": "selectedShortDateFormat"; "required": false; }; }, {}, ["allDaySlotTemplate", "allDayEventTemplate"], never, true, never>;
}
