/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { TimelineBase } from './timeline-base';
import { ViewContextService } from '../view-context.service';
import { ViewStateService } from '../view-state.service';
import * as i0 from "@angular/core";
/**
 * The component for rendering the **Month** timeline view.
 */
export declare class TimelineMonthViewComponent extends TimelineBase {
    /**
     * @hidden
     */
    get title(): string;
    /**
     * The long-date format for displaying the
     * selected date in the Scheduler toolbar.
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * > Note: If [numberOfMonths](#toc-numberofmonths) > 1, the default format value shows a range - `'{0:Y} - {1:Y}'`, where `0` is the start and `1` is the end date.
     * @default '{0:Y}'
     */
    set selectedDateFormat(format: string);
    get selectedDateFormat(): string;
    private _selectedDateFormat;
    /**
     * The short-date format for displaying the
     * selected date in the Scheduler toolbar.
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * > Note: If [numberOfMonths](#toc-numberofmonths) > 1, the default format value shows a range - `'{0:y} - {1:y}'`, where `0` is the start and `1` is the end date.
     * @default '{0:y}'
     */
    set selectedShortDateFormat(format: string);
    get selectedShortDateFormat(): string;
    private _selectedShortDateFormat;
    /**
     * Specifies the number of months that the view will render.
     * > Normalized to `1` if the provided value is <= 0.
     * @default 1
     */
    set numberOfMonths(months: number);
    get numberOfMonths(): number;
    private _numberOfMonths;
    /**
     * The invariant name for this view.
     * @default 'timelineMonth'
     */
    readonly name: string;
    /**
     * @hidden
     */
    getStartDate: (selectedDate: Date) => Date;
    /**
     * @hidden
     */
    getEndDate: (selectedDate: Date) => Date;
    /**
     * @hidden
     */
    getNextDate: (date: Date, count: number) => Date;
    constructor(localization: LocalizationService, changeDetector: ChangeDetectorRef, viewContext: ViewContextService, viewState: ViewStateService);
    static ɵfac: i0.ɵɵFactoryDeclaration<TimelineMonthViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TimelineMonthViewComponent, "kendo-scheduler-timeline-month-view", never, { "selectedDateFormat": { "alias": "selectedDateFormat"; "required": false; }; "selectedShortDateFormat": { "alias": "selectedShortDateFormat"; "required": false; }; "numberOfMonths": { "alias": "numberOfMonths"; "required": false; }; }, {}, never, never, true, never>;
}
