/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { TimelineBase } from './timeline-base';
import { ViewContextService } from '../view-context.service';
import { ViewStateService } from '../view-state.service';
import * as i0 from "@angular/core";
/**
 * The component for rendering the **Timeline** view.
 */
export declare class TimelineViewComponent extends TimelineBase {
    /**
     * @hidden
     */
    get title(): string;
    /**
     * The long-date format for displaying the
     * selected date in the Scheduler toolbar.
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * > Note: If [numberOfDays](#toc-numberofdays) > 1, the default format value shows a range - `'{0:D} - {1:D}'`, where `0` is the start and `1` is the end date.
     * @default '{0:D}'
     */
    set selectedDateFormat(format: string);
    get selectedDateFormat(): string;
    private _selectedDateFormat;
    /**
     * The short-date format for displaying the
     * selected date in the Scheduler toolbar.
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * > Note: If [numberOfDays](#toc-numberofdays) > 1, the default format value shows a range - `'{0:d} - {1:d}'`, where `0` is the start and `1` is the end date.
     * @default '{0:d}'
     */
    set selectedShortDateFormat(format: string);
    get selectedShortDateFormat(): string;
    private _selectedShortDateFormat;
    /**
     * Specifies the number of days that the view will render.
     * > Normalized to `1` if the provided value is <= 0.
     * @default 1
     */
    set numberOfDays(days: number);
    get numberOfDays(): number;
    private _numberOfDays;
    /**
     * The invariant name for this view.
     * @default 'timeline'
     */
    readonly name: string;
    constructor(localization: LocalizationService, changeDetector: ChangeDetectorRef, viewContext: ViewContextService, viewState: ViewStateService);
    static ɵfac: i0.ɵɵFactoryDeclaration<TimelineViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TimelineViewComponent, "kendo-scheduler-timeline-view", never, { "selectedDateFormat": { "alias": "selectedDateFormat"; "required": false; }; "selectedShortDateFormat": { "alias": "selectedShortDateFormat"; "required": false; }; "numberOfDays": { "alias": "numberOfDays"; "required": false; }; }, {}, never, never, true, never>;
}
