/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { TimelineBase } from './timeline-base';
import { IntlService } from '@progress/kendo-angular-intl';
import { ViewContextService } from '../view-context.service';
import { ViewStateService } from '../view-state.service';
import * as i0 from "@angular/core";
/**
 * The component for rendering the **Week** timeline view.
 */
export declare class TimelineWeekViewComponent extends TimelineBase {
    /**
     * @hidden
     */
    get title(): string;
    /**
     * The long-date format that will be used for displaying the
     * selected date in the Scheduler toolbar.
     * Defaults to `{0:D} - {1:D}`
     * where `0` is the start and `1` is the end date
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * @default '{0:D} - {1:D}'
     */
    selectedDateFormat: string;
    /**
     * The short date format that will be used for displaying the
     * selected date in the Scheduler toolbar.
     * Defaults to `{0:d} - {1:d}`
     * where `0` is the start and `1` is the end date
     * ([more information]({% slug parsingandformatting_intl %}#toc-date-formatting)).
     * @default '{0:d} - {1:d}'
     */
    selectedShortDateFormat: string;
    /**
    * Specifies the number of weeks that the view will render.
    * @default 1
    */
    set numberOfWeeks(weeks: number);
    get numberOfWeeks(): number;
    private _numberOfWeeks;
    /**
     * The invariant name for this view.
     * @default 'timelineWeek'
     */
    readonly name: string;
    constructor(_intl: IntlService, localization: LocalizationService, changeDetector: ChangeDetectorRef, viewContext: ViewContextService, viewState: ViewStateService);
    /**
     * @hidden
     */
    getStartDate: (selectedDate: Date) => Date;
    static ɵfac: i0.ɵɵFactoryDeclaration<TimelineWeekViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TimelineWeekViewComponent, "kendo-scheduler-timeline-week-view", never, { "selectedDateFormat": { "alias": "selectedDateFormat"; "required": false; }; "selectedShortDateFormat": { "alias": "selectedShortDateFormat"; "required": false; }; "numberOfWeeks": { "alias": "numberOfWeeks"; "required": false; }; }, {}, never, never, true, never>;
}
