/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { DateRange, OngoingEventsSettings } from '../../types';
import { ViewContextService } from '../view-context.service';
import { ViewStateService } from '../view-state.service';
import { ConfigurationViewBase } from '../common/configuration-view-base';
import { IntlService } from '@progress/kendo-angular-intl';
import * as i0 from "@angular/core";
/**
 * The component for rendering the **Year** view.
 */
export declare class YearViewComponent extends ConfigurationViewBase {
    private intl;
    /**
     * The long-date format for displaying the
     * selected year in the Scheduler toolbar.
     * For more information, see [Parsing and Formatting Dates and Numbers]({% slug parsingandformatting_intl %}#toc-date-formatting).
     * @default '{0:yyy}'
     */
    selectedDateFormat: string;
    /**
     * The short-date format for displaying the
     * selected year in the Scheduler toolbar.
     * For more information, see [Parsing and Formatting Dates and Numbers]({% slug parsingandformatting_intl %}#toc-date-formatting).
     * @default '{0:yyy}'
     */
    selectedShortDateFormat: string;
    /**
     * @hidden
     */
    get title(): string;
    /**
     * @hidden
     */
    highlightOngoingEvents: boolean | OngoingEventsSettings;
    /**
     * The invariant name for this view.
     * @default 'year'
     */
    readonly name: string;
    constructor(localization: LocalizationService, changeDetector: ChangeDetectorRef, viewContext: ViewContextService, viewState: ViewStateService, intl: IntlService);
    /**
     * @hidden
     */
    dateRange(date: Date): DateRange;
    /**
     * @hidden
     */
    newRange(date: Date, direction?: 1 | -1): Date;
    static ɵfac: i0.ɵɵFactoryDeclaration<YearViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<YearViewComponent, "kendo-scheduler-year-view", never, { "selectedDateFormat": { "alias": "selectedDateFormat"; "required": false; }; "selectedShortDateFormat": { "alias": "selectedShortDateFormat"; "required": false; }; "highlightOngoingEvents": { "alias": "highlightOngoingEvents"; "required": false; }; }, {}, never, never, true, never>;
}
